@@ -379,6 +379,9 @@ class WorxCloud(dict):
             if "st" in data["dat"]:
                 device.statistics = Statistic(data["dat"]["st"])
 
+                if len(device.blades) != 0:
+                    device.blades.set_data(data["dat"]["st"])
+
             # Get orientation if available.
             if "dmp" in data["dat"]:
                 device.orientation = Orientation(data["dat"]["dmp"])
@@ -413,6 +416,13 @@ class WorxCloud(dict):
                 # Map current zone to zone index
                 device.zone.current = device.zone.indicies[device.zone.index]
 
+                # Map next zone to zone index
+                device.zone.next = (
+                    device.zone.indicies[device.zone.index + 1]
+                    if device.zone.index < 9
+                    else 0
+                )
+
             # Fetch main schedule
             if "sc" in data["cfg"]:
                 if "ots" in data["cfg"]["sc"]:
