@@ -3,7 +3,12 @@ from __future__ import annotations
 
 import json
 
-from ..exceptions import NoOneTimeScheduleError, NoPartymodeError, OfflineError
+from ..exceptions import (
+    NoOneTimeScheduleError,
+    NoPartymodeError,
+    OfflineError,
+    RequestException,
+)
 from ..helpers import get_logger
 from .capability import DeviceCapability
 from .mqtt import Command
@@ -170,7 +175,7 @@ class Actions:
         else:
             raise OfflineError("The device is currently offline, no action was sent.")
 
-    def setzone(self, zone: str) -> None:
+    def setzone(self, zone: str | int) -> None:
         """Set zone to be mowed when next mowing task is started.
 
         Args:
@@ -183,9 +188,14 @@ class Actions:
             if not isinstance(zone, int):
                 zone = int(zone)
 
+            if self.zone["starting_point"][zone] == 0:
+                raise RequestException("Cannot request this zone as it is not defined.")
+
             current = self.zone["indicies"]
             new_zones = current
-            while not new_zones[self.zone.current] == zone:
+
+            next_index = self.zone["index"] + 1 if self.zone["index"] < 9 else 0
+            while not new_zones[next_index] == zone:
                 tmp = []
                 tmp.append(new_zones[9])
                 for i in range(0, 9):
