@@ -1,8 +1,11 @@
 """Device capabilities."""
 from __future__ import annotations
 
+import logging
 from enum import IntEnum
 
+from ..events import EventHandler, LandroidEvent
+
 
 class DeviceCapability(IntEnum):
     """Available device capabilities."""
@@ -28,6 +31,7 @@ class Capability(int):
         """Initialize an empty capability list."""
         super().__init__()
         self.__int__ = 0
+        self.ready = False
 
     def add(self, capability: DeviceCapability) -> None:
         """Add capability to the list."""
