@@ -208,7 +208,7 @@ class MQTT(mqtt.Client, LDict):
         topic = self.topics[device]["in"]
 
         data = data.replace("'", '"')
-        if not re.match('^\{[A-ZÆØÅa-zæøå0-9:,\[\]"{} \n]*\}$', data):
+        if not re.match('^\{[A-ZÆØÅa-zæøå0-9:,\[\]"{} \n-]*\}$', data):
             data = "{" + data + "}"
 
         log_msg = f'Sending "{data}" to "{recipient.name}" on "{topic}"'
